ScopeRegistry class abstract interface

An interface for registering available dependency scopes.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init(RootBinding<RootScope> rootBinding, {List<ScopeBinding<FeatureScope>>? featureBindings}) Future<void>
Initializes the registry.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerScopeBinding<S extends FeatureScope>(ScopeBinding<S> binding) → void
Registers a binding for a FeatureScope type to its factory.
registerScopeFactory<S extends FeatureScope>(ScopeFactory<S> factory) → void
Registers a factory function for creating instances of a specific FeatureScope type.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited